# Credits

## Development Lead

-   Benedikt Reinartz ([@filmor](https://github.com/filmor))
-   Victor Milovanov ([@lostmsu](https://github.com/lostmsu))

## Former Development Leads
-   Barton Cline ([@BartonCline](https://github.com/BartonCline))
-   Brian Lloyd ([@brianlloyd](https://github.com/brianlloyd))
-   David Anthoff ([@davidanthoff](https://github.com/davidanthoff))
-   Denis Akhiyarov ([@denfromufa](https://github.com/denfromufa))
-   Tony Roberts ([@tonyroberts](https://github.com/tonyroberts))
-   Victor Uriarte ([@vmuriart](https://github.com/vmuriart))

## Contributors

-   Alex Earl ([@slide](https://github.com/slide))
-   Alex Helms ([@alexhelms](https://github.com/alexhelms))
-   Alexandre Catarino([@AlexCatarino](https://github.com/AlexCatarino))
-   Andrey Sant'Anna ([@andreydani](https://github.com/andreydani))
-   Arvid JB ([@ArvidJB](https://github.com/ArvidJB))
-   Benoît Hudson ([@benoithudson](https://github.com/benoithudson))
-   Bradley Friedman ([@leith-bartrich](https://github.com/leith-bartrich))
-   Callum Noble ([@callumnoble](https://github.com/callumnoble))
-   Christian Heimes ([@tiran](https://github.com/tiran))
-   Christoph Gohlke ([@cgohlke](https://github.com/cgohlke))
-   Christopher Bremner ([@chrisjbremner](https://github.com/chrisjbremner))
-   Christopher Pow ([@christopherpow](https://github.com/christopherpow))
-   Daniel Fernandez ([@fdanny](https://github.com/fdanny))
-   Daniel Santana ([@dgsantana](https://github.com/dgsantana))
-   Dave Hirschfeld ([@dhirschfeld](https://github.com/dhirschfeld))
-   David Lassonde ([@lassond](https://github.com/lassond))
-   David Lechner ([@dlech](https://github.com/dlech))
-   Dmitriy Se ([@dmitriyse](https://github.com/dmitriyse))
-   Florian Treurniet ([@ftreurni](https://github.com/ftreurni))
-   He-chien Tsai ([@t3476](https://github.com/t3476))
-   Inna Wiesel ([@inna-w](https://github.com/inna-w))
-   Ivan Cronyn ([@cronan](https://github.com/cronan))
-   Jan Krivanek ([@jakrivan](https://github.com/jakrivan))
-   Jeff Reback ([@jreback](https://github.com/jreback))
-   Jeff Robbins ([@jeff17robbins](https://github.com/jeff17robbins))
-   Joe Frayne ([@jfrayne](https://github.com/jfrayne))
-   Joe Lidbetter ([@jmlidbetter](https://github.com/jmlidbetter))
-   Joe Savage ([@s4v4g3](https://github.com/s4v4g3))
-   John Burnett ([@johnburnett](https://github.com/johnburnett))
-   John Wilkes ([@jbw3](https://github.com/jbw3))
-   Luke Stratman ([@lstratman](https://github.com/lstratman))
-   Konstantin Posudevskiy ([@konstantin-posudevskiy](https://github.com/konstantin-posudevskiy))
-   Matthias Dittrich ([@matthid](https://github.com/matthid))
-   Meinrad Recheis ([@henon](https://github.com/henon))
-   Mohamed Koubaa ([@koubaa](https://github.com/koubaa))
-   Patrick Stewart ([@patstew](https://github.com/patstew))
-   Raphael Nestler ([@rnestler](https://github.com/rnestler))
-   Rickard Holmberg ([@rickardraysearch](https://github.com/rickardraysearch))
-   Sam Winstanley ([@swinstanley](https://github.com/swinstanley))
-   Sean Freitag ([@cowboygneox](https://github.com/cowboygneox))
-   Serge Weinstock ([@sweinst](https://github.com/sweinst))
-   Simon Mourier ([@smourier](https://github.com/smourier))
-   Viktoria Kovescses ([@vkovec](https://github.com/vkovec))
-   Ville M. Vainio ([@vivainio](https://github.com/vivainio))
-   Virgil Dupras ([@hsoft](https://github.com/hsoft))
-   Wenguang Yang ([@yagweb](https://github.com/yagweb))
-   William Sardar ([@williamsardar])(https://github.com/williamsardar)
-   Xavier Dupré ([@sdpython](https://github.com/sdpython))
-   Zane Purvis ([@zanedp](https://github.com/zanedp))
-   ([@bltribble](https://github.com/bltribble))
-   ([@civilx64](https://github.com/civilx64))
-   ([@GSPP](https://github.com/GSPP))
-   ([@omnicognate](https://github.com/omnicognate))
-   ([@OneBlue](https://github.com/OneBlue))
-   ([@rico-chet](https://github.com/rico-chet))
-   ([@rmadsen-ks](https://github.com/rmadsen-ks))
-   ([@stonebig](https://github.com/stonebig))
-   ([@testrunner123](https://github.com/testrunner123))
-   ([@DanBarzilian](https://github.com/DanBarzilian))

